# react-smart-hooks

A React component to generate `React Smart Hooks` for rendering to the DOM.

## Installation

**npm**

```bash
npm install react-smart-hooks
```

**yarn**

```bash
yarn add react-smart-hooks
```

**pnpm**

```bash
pnpm add react-smart-hooks
```

## Usage

The `react-smart-hooks` library provides a streamlined single-component export to simplify the implementation of breadcrumb functionality.

All examples are presented using modern JavaScript modules and syntax. Moreover, compatibility with CommonJS, as evidenced by the use of require(`react-smart-hooks`), is also maintained.

### `React Smart Hooks`

```js
import React, { FC } from "react";
import { useWindowSize, useLocalStorage, useOutsideClick } from "react-smart-hooks";

const MyComponent:FC = () => {
  const windowSize = useWindowSize();
  const [first, setfirst] = useState<boolean>(false);
  const [click, setClick] = useLocalStorage({ key: 'demo-click', initialValue: true });

  useOutsideClick({ refs: [buttonRef, divRef], onClick: () => setfirst(false) });

  const { width, height } = windowSize;
  console.log(width, height);
  console.log(click);
  return (
      <>
        <div ref={divRef} className={first ? "active" : ""}>
          <button ref={buttonRef} type="button" onClick={() => { setfirst(!first); setClick(!click) }}>Click</button>
        </div>
      </>
  );
};
export default MyComponent;
```

## Props

| Name                 | Type     | Default Value | Description                                                                                                                                                |
| -------------------- | -------- | ------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------- |
| **useWindowSize**    | Hooks    | " "           |                                                                                                                                                            |
| **useLocalStorage**  | Hooks    | " "           |                                                                                                                                                            |
| **useOutsideClick**  | Hooks    | " "           |                                                                                                                                                            |
